#
# spec file for package sca-appliance-broker
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sca_common sca
%define sca_webdir /srv/www/htdocs/%{sca_common}
%define sca_configdir %{_sysconfdir}/%{sca_common}

Name:           sca-appliance-broker
Version:        1.3.2
Release:        1.4
Summary:        Supportconfig Analysis Appliance Broker
License:        GPL-2.0-only
URL:            https://github.com/g23guy/sca-appliance-broker
Group:          System/Monitoring
Source:         %{name}-%{version}.tar.gz
Requires:       sca-appliance-common
BuildArch:      noarch

%description
Monitors inbound supportconfig archives and is responsible for
assigning new and retry archives states for appropriate agent analysis.

See %{_docdir}/sca-appliance-common/COPYING.GPLv2

%prep
%setup -q

%build
gzip -9f man/*8
gzip -9f man/*5

%install
pwd;ls -la
mkdir -p %{buildroot}%{sca_configdir}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{sca_webdir}
install -d %{buildroot}%{_mandir}/man8
install -d %{buildroot}%{_mandir}/man5
install -d %{buildroot}%{_docdir}/%{name}
install -m 644 config/*.conf %{buildroot}%{sca_configdir}
install -m 644 config/* %{buildroot}%{_docdir}/%{name}
install -m 644 websca/index.html %{buildroot}%{_docdir}/%{name}
install -m 640 websca/* %{buildroot}%{sca_webdir}
install -m 544 bin/* %{buildroot}%{_sbindir}
install -m 644 schema/* %{buildroot}%{_docdir}/%{name}
install -m 644 docs/* %{buildroot}%{_docdir}/%{name}
install -m 644 man/*.8.gz %{buildroot}%{_mandir}/man8
install -m 644 man/*.5.gz %{buildroot}%{_mandir}/man5

%files
%defattr(-,root,root)
%dir %{_docdir}/%{name}
%dir %attr(-,wwwrun,www) %{sca_webdir}
%dir %{sca_configdir}
%{_sbindir}/scadb
%{_sbindir}/sdbroker
%{_sbindir}/sdbroker-monitor
%{_sbindir}/setup-sca
%{_sbindir}/setup-sdagent
%{_sbindir}/setup-sdbroker
%attr(-,wwwrun,www) %{sca_webdir}/*
%config %{sca_configdir}/sdbroker.conf
%doc %{_mandir}/man8/*
%doc %{_mandir}/man5/*
%attr(-,wwwrun,www) %{_docdir}/%{name}/index.html
%doc %{_docdir}/%{name}/*

%post
if [[ -s /srv/www/htdocs/index.html ]]; then
	if grep -i '<html><body><h1>It works!</h1></body></html>' /srv/www/htdocs/index.html &>/dev/null; then
		mv /srv/www/htdocs/index.html /srv/www/htdocs/index.html.sca_orig
		cp -a %{_docdir}/%{name}/index.html /srv/www/htdocs/
	else
		echo
		echo "WARNING: File already exists: /srv/www/htdocs/index.html"
		echo " Redirector %{_docdir}/%{name}/index.html will not be installed."
		echo
	fi
else
	cp -a %{_docdir}/%{name}/index.html /srv/www/htdocs/
fi

%postun
if [[ -s /srv/www/htdocs/index.html.sca_orig ]]; then
	mv /srv/www/htdocs/index.html.sca_orig /srv/www/htdocs/index.html
elif grep -i 'sca/index.php' /srv/www/htdocs/index.html &>/dev/null; then
	mv /srv/www/htdocs/index.html /srv/www/htdocs/index.html.sca_redirector
fi

%changelog
* Wed Jun 29 2022 Jason Record <jason.record@suse.com>
- setup-sca checks for php8 (bsc#1201011)
* Tue Mar 16 2021 jason.record@gmail.com
- Correctly check for the web and scripting module (bsc#1183601)
* Fri Mar 12 2021 jason.record@suse.com
- Removed Novell references (bsc#1183471)
- New supportconfigs with xz compression are processed (bsc#1183343)
- sdbroker-monitor runs without error (bsc#1183466)
* Thu Jan 25 2018 jason.record@suse.com
- Clarified web user set string (bsc#1077666)
* Mon Jan 22 2018 jason.record@suse.com
- Detect web and scripting module
* Fri Jan 19 2018 jason.record@suse.com
- Active services as needed or exclude activation with -a
* Tue Jan  9 2018 jason.record@suse.com
- Correct ownership of /var/lib/php? (bsc#1075216)
* Wed Jan  3 2018 jason.record@suse.com
- Removed additional /usr/bin/[ references
* Tue Jan  2 2018 jason.record@suse.com
- Removed references to /usr/bin/[
* Mon Dec 18 2017 jason.record@suse.com
- Updated spec file with spec-cleaner suggestions
- Removed COPYING.GPLv2
- Updated schema locations
* Fri Jun  2 2017 jason.record@suse.com
- Fixed incorrect SLE12SP2 global library value (bsc#1042515)
- setup-sca correctly checks mysql (bsc#975651)
* Fri Jul  4 2014 jrecord@suse.com
- Updated man pages
- Uniform email from address
* Fri Jun 13 2014 jrecord@suse.com
- Added email from address
- Fixed restart error in setup-sca
* Mon Jun  9 2014 jrecord@suse.com
- Fixed header lines
- Removed targets for opening tabs
- Added SR and OES views to index.php (bnc#881000)
* Wed Jun  4 2014 jrecord@suse.com
- Fixed pattern source links
* Wed May 28 2014 jrecord@suse.com
- Fixed FTP server validation (bnc#879714)
- Added summary usage to setup-sca (bnc#879715)
* Mon May 19 2014 jrecord@suse.com
- Checks for mysqli library with setup-sca
* Fri May 16 2014 jrecord@suse.com
- Added web module checks to setup-sca
- setup-sca now checks for PHP modules (bnc#877402)
- SDP database reference updated (bnc#876919)
- Report checks web login (bnc#876347)
- Check for reportfull.php before running
* Mon May 12 2014 jrecord@suse.com
- Added ArchiveID to scadb active,done,pending,error
- Converted reportfull.php to mysqli
- Fixed connection errors
- Converted mysql PHP calls to mysqli (bnc#876918)
- Fixed build errors for common directory
* Wed Apr 23 2014 jrecord@suse.com
- Added scadb results to find pattern results in the db
* Tue Apr 22 2014 jrecord@suse.com
- Added web password to setup-sdbroker and setup-sca (bnc#874632)
- Removed clear screen
- Added scadb config to show current configuration
* Wed Mar 26 2014 jrecord@suse.com
- User password removed from setup-sca
- Fixed setup-sca status checks (bnc#870402)
* Thu Mar 20 2014 jrecord@suse.com
- Added current report options to scadb
- Added missing content to scadb man page
- Updated curl error processing
- Corrected man page location
- Fixed man page headers
- Moved section 1 man pages to section 8
- Updated man page content
- Added setup-sca.8 and sdbroker-monitor.8 man pages
* Thu Mar 13 2014 jrecord@suse.com
- Fixed FSF address in files
- Removed setup-sdp.1 (bnc#868235)
- Change to System/Monitoring spec Group
* Sat Feb  8 2014 jrecord@suse.com
- Packaged COPYING.GPLv2
* Fri Jan 31 2014 jrecord@suse.com
- added postun
- fixed supportconfig date sort order
- updated docs.html with web-config.php
- added supportconfig run date to index.php
- added report tag to scadb to manuall generate an html report
- Converted to .changes
* Thu Jan 23 2014 jrecord@suse.com
- fixed config dir references in websca/docs.html
- added pattern update in websca/docs.html
- commented out debug statements to avoid xss
* Sat Jan 18 2014 jrecord@suse.com
- documented backup and restore
* Fri Jan 17 2014 jrecord@suse.com
- relocated files according to FHS
- updated DEF_HOME for FHS in /var/tmp
- fixed incorrect bin paths
* Tue Jan  7 2014 jrecord@suse.com
- updated docs with archive file link
- updated docs with --no-gpg-checks
- separated sca-appliance-common files
* Tue Dec 24 2013 jrecord@suse.com
- setup-sca package names changes
- fixed blank hypervisor lines
- sdbroker no longer inserts FileLocation
* Sat Dec 21 2013 jrecord@suse.com
- separated as individual RPM package
- SCA reports page sorts by all columns
- fixed SCA XSS vulnerabilities
- fixed SCA SQL injection vulnerabilities
